@@ -17,6 +17,7 @@ from galaxy.util import (
     directory_hash_id,
     safe_relpath,
     umask_fix_perms,
+    unlink,
 )
 from galaxy.util.sleeper import Sleeper
 from .s3 import parse_config_xml
@@ -117,7 +118,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
 
     @staticmethod
     def _get_connection(provider, credentials):
-        log.debug("Configuring `{}` Connection".format(provider))
+        log.debug(f"Configuring `{provider}` Connection")
         if provider == "aws":
             config = {"aws_access_key": credentials["access_key"],
                       "aws_secret_key": credentials["secret_key"]}
@@ -132,7 +133,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
             config = {"gcp_service_creds_file": credentials["credentials_file"]}
             connection = CloudProviderFactory().create_provider(ProviderList.GCP, config)
         else:
-            raise Exception("Unsupported provider `{}`.".format(provider))
+            raise Exception(f"Unsupported provider `{provider}`.")
 
         # Ideally it would be better to assert if the connection is
         # authorized to perform operations required by ObjectStore
@@ -215,7 +216,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
             elif provider == "google":
                 cre = auth_element.get("credentials_file")
                 if not os.path.isfile(cre):
-                    msg = "The following file specified for GCP credentials not found: {}".format(cre)
+                    msg = f"The following file specified for GCP credentials not found: {cre}"
                     log.error(msg)
                     raise OSError(msg)
                 if cre is None:
@@ -223,7 +224,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
                 config["auth"] = {
                     "credentials_file": cre}
             else:
-                msg = "Unsupported provider `{}`.".format(provider)
+                msg = f"Unsupported provider `{provider}`."
                 log.error(msg)
                 raise Exception(msg)
 
@@ -321,7 +322,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
         except Exception:
             # These two generic exceptions will be replaced by specific exceptions
             # once proper exceptions are exposed by CloudBridge.
-            log.exception("Could not get bucket '{}'".format(bucket_name))
+            log.exception(f"Could not get bucket '{bucket_name}'")
         raise Exception
 
     def _fix_permissions(self, rel_path):
@@ -366,10 +367,10 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
             return os.path.join(base, rel_path)
 
         # S3 folders are marked by having trailing '/' so add it now
-        rel_path = '%s/' % rel_path
+        rel_path = f'{rel_path}/'
 
         if not dir_only:
-            rel_path = os.path.join(rel_path, alt_name if alt_name else "dataset_%s.dat" % self._get_object_id(obj))
+            rel_path = os.path.join(rel_path, alt_name if alt_name else f"dataset_{self._get_object_id(obj)}.dat")
         return rel_path
 
     def _get_cache_path(self, rel_path):
@@ -439,7 +440,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
                 log.debug("Parallel pulled key '%s' into cache to %s", rel_path, self._get_cache_path(rel_path))
                 ncores = multiprocessing.cpu_count()
                 url = key.generate_url(7200)
-                ret_code = subprocess.call("axel -a -n {} '{}'".format(ncores, url))
+                ret_code = subprocess.call(f"axel -a -n {ncores} '{url}'")
                 if ret_code == 0:
                     return True
             else:
@@ -568,7 +569,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
                 os.makedirs(cache_dir)
 
             if not dir_only:
-                rel_path = os.path.join(rel_path, alt_name if alt_name else "dataset_%s.dat" % self._get_object_id(obj))
+                rel_path = os.path.join(rel_path, alt_name if alt_name else f"dataset_{self._get_object_id(obj)}.dat")
                 open(os.path.join(self.staging_path, rel_path), 'w').close()
                 self._push_to_os(rel_path, from_string='')
 
@@ -608,7 +609,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
             # with all the files in it. This is easy for the local file system,
             # but requires iterating through each individual key in S3 and deleing it.
             if entire_dir and extra_dir:
-                shutil.rmtree(self._get_cache_path(rel_path))
+                shutil.rmtree(self._get_cache_path(rel_path), ignore_errors=True)
                 results = self.bucket.objects.list(prefix=rel_path)
                 for key in results:
                     log.debug("Deleting key %s", key.name)
@@ -616,7 +617,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
                 return True
             else:
                 # Delete from cache first
-                os.unlink(self._get_cache_path(rel_path))
+                unlink(self._get_cache_path(rel_path), ignore_errors=True)
                 # Delete from S3 as well
                 if self._key_exists(rel_path):
                     key = self.bucket.objects.get(rel_path)
