@@ -1,30 +1,29 @@
 """
-Object Store plugin for the Integrated Rule-Oriented Data Store (iRODS)
+Object Store plugin for the Integrated Rule-Oriented Data System (iRODS)
 """
 import logging
 import os
 import shutil
-from contextlib import contextmanager
 from datetime import datetime
 from functools import partial
-try:
-    from pathlib import Path
-except ImportError:
-    # Use backport on python 2
-    from pathlib2 import Path
+from pathlib import Path
 
 try:
     import irods
     import irods.keywords as kw
     from irods.exception import CollectionDoesNotExist
     from irods.exception import DataObjectDoesNotExist
-    from irods.exception import NetworkException
     from irods.session import iRODSSession
 except ImportError:
     irods = None
 
 from galaxy.exceptions import ObjectInvalid, ObjectNotFound
-from galaxy.util import directory_hash_id, ExecutionTimer, umask_fix_perms
+from galaxy.util import (
+    directory_hash_id,
+    ExecutionTimer,
+    umask_fix_perms,
+    unlink,
+)
 from galaxy.util.path import safe_relpath
 from ..objectstore import DiskObjectStore
 
@@ -35,7 +34,7 @@ log = logging.getLogger(__name__)
 
 
 def _config_xml_error(tag):
-    msg = 'No {tag} element in config XML tree'.format(tag=tag)
+    msg = f'No {tag} element in config XML tree'
     raise Exception(msg)
 
 
@@ -68,7 +67,7 @@ def parse_config_xml(config_xml):
         host = c_xml[0].get('host', None)
         port = int(c_xml[0].get('port', 0))
         timeout = int(c_xml[0].get('timeout', 30))
-        poolsize = int(c_xml[0].get('poolsize', 3))
+        refresh_time = int(c_xml[0].get('refresh_time', 300))
 
         c_xml = config_xml.findall('cache')
         if not c_xml:
@@ -97,7 +96,7 @@ def parse_config_xml(config_xml):
                 'host': host,
                 'port': port,
                 'timeout': timeout,
-                'poolsize': poolsize
+                'refresh_time': refresh_time,
             },
             'cache': {
                 'size': cache_size,
@@ -111,32 +110,7 @@ def parse_config_xml(config_xml):
         raise
 
 
-def acquire_session(host='localhost', port='1247', user='rods', password='rods', zone='tempZone', timeout='30'):
-    session = iRODSSession(host=host, port=port, user=user, password=password, zone=zone)
-    # Set connection timeout
-    session.connection_timeout = timeout
-    return session
-
-
-def release_session(session):
-    # This call will cleanup all the connections in the connection pool
-    # OSError sometimes happens on GitHub Actions, after the test has successfully completed. Ignore it if it happens.
-    try:
-        session.cleanup()
-    except OSError:
-        pass
-
-
-@contextmanager
-def managed_session(host='localhost', port='1247', user='rods', password='rods', zone='tempZone', timeout='30'):
-    session = acquire_session(host=host, port=port, user=user, password=password, zone=zone, timeout=timeout)
-    try:
-        yield session
-    finally:
-        release_session(session)
-
-
-class CloudConfigMixin(object):
+class CloudConfigMixin:
 
     def _config_to_dict(self):
         return {
@@ -154,7 +128,7 @@ class CloudConfigMixin(object):
                 'host': self.host,
                 'port': self.port,
                 'timeout': self.timeout,
-                'poolsize': self.poolsize,
+                'refresh_time': self.refresh_time,
             },
             'cache': {
                 'size': self.cache_size,
@@ -165,14 +139,14 @@ class CloudConfigMixin(object):
 
 class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
     """
-    Object store that stores objects as data objects in an iRODS collections. A local cache
+    Object store that stores files as data objects in an iRODS Zone. A local cache
     exists that is used as an intermediate location for files between Galaxy and iRODS.
     """
 
     store_type = 'irods'
 
     def __init__(self, config, config_dict):
-        reload_timer = ExecutionTimer()
+        ipt_timer = ExecutionTimer()
         super().__init__(config, config_dict)
 
         auth_dict = config_dict.get('auth')
@@ -212,9 +186,9 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         self.timeout = connection_dict.get('timeout')
         if self.timeout is None:
             _config_dict_error('connection->timeout')
-        self.poolsize = connection_dict.get('poolsize')
-        if self.poolsize is None:
-            _config_dict_error('connection->poolsize')
+        self.refresh_time = connection_dict.get('refresh_time')
+        if self.refresh_time is None:
+            _config_dict_error('connection->refresh_time')
 
         cache_dict = config_dict['cache']
         if cache_dict is None:
@@ -234,8 +208,25 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         if irods is None:
             raise Exception(IRODS_IMPORT_MESSAGE)
 
-        self.home = "/" + self.zone + "/home/" + self.username
-        log.debug("irods __init__ %s", reload_timer)
+        self.home = f"/{self.zone}/home/{self.username}"
+
+        if irods is None:
+            raise Exception(IRODS_IMPORT_MESSAGE)
+
+        self.session = iRODSSession(host=self.host, port=self.port, user=self.username, password=self.password, zone=self.zone, refresh_time=self.refresh_time)
+        # Set connection timeout
+        self.session.connection_timeout = self.timeout
+        log.debug("irods_pt __init__: %s", ipt_timer)
+
+    def shutdown(self):
+        # This call will cleanup all the connections in the connection pool
+        # OSError sometimes happens on GitHub Actions, after the test has successfully completed. Ignore it if it happens.
+        ipt_timer = ExecutionTimer()
+        try:
+            self.session.cleanup()
+        except OSError:
+            pass
+        log.debug("irods_pt shutdown: %s", ipt_timer)
 
     @classmethod
     def parse_xml(cls, config_xml):
@@ -258,8 +249,9 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
                 umask_fix_perms(path, self.config.umask, 0o666, self.config.gid)
 
     def _construct_path(self, obj, base_dir=None, dir_only=None, extra_dir=None, extra_dir_at_root=False, alt_name=None, obj_dir=False, **kwargs):
+        ipt_timer = ExecutionTimer()
         # extra_dir should never be constructed from provided data but just
-        # make sure there are no shenannigans afoot
+        # make sure there are no shenanigans afoot
         if extra_dir and extra_dir != os.path.normpath(extra_dir):
             log.warning('extra_dir is not normalized: %s', extra_dir)
             raise ObjectInvalid("The requested object is invalid")
@@ -284,10 +276,12 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
             rel_path = os.path.join(rel_path, str(self._get_object_id(obj)))
         if base_dir:
             base = self.extra_dirs.get(base_dir)
+            log.debug("irods_pt _construct_path: %s", ipt_timer)
             return os.path.join(base, rel_path)
 
         if not dir_only:
-            rel_path = os.path.join(rel_path, alt_name if alt_name else "dataset_%s.dat" % self._get_object_id(obj))
+            rel_path = os.path.join(rel_path, alt_name if alt_name else f"dataset_{self._get_object_id(obj)}.dat")
+        log.debug("irods_pt _construct_path: %s", ipt_timer)
         return rel_path
 
     def _get_cache_path(self, rel_path):
@@ -295,43 +289,41 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
 
     # rel_path is file or folder?
     def _get_size_in_irods(self, rel_path):
-        with managed_session(host=self.host, port=self.port, user=self.username, password=self.password, zone=self.zone, timeout=self.timeout) as session:
-            p = Path(rel_path)
-            data_object_name = p.stem + p.suffix
-            subcollection_name = p.parent
+        ipt_timer = ExecutionTimer()
+        p = Path(rel_path)
+        data_object_name = p.stem + p.suffix
+        subcollection_name = p.parent
 
-            collection_path = self.home + "/" + str(subcollection_name)
-            data_object_path = collection_path + "/" + str(data_object_name)
+        collection_path = f"{self.home}/{str(subcollection_name)}"
+        data_object_path = f"{collection_path}/{str(data_object_name)}"
 
-            try:
-                data_obj = session.data_objects.get(data_object_path)
-                return data_obj.__sizeof__()
-            except (DataObjectDoesNotExist, CollectionDoesNotExist):
-                log.warn("Collection or data object (%s) does not exist", data_object_path)
-                return -1
-            except NetworkException as e:
-                log.exception(e)
-                return -1
+        try:
+            data_obj = self.session.data_objects.get(data_object_path)
+            return data_obj.__sizeof__()
+        except (DataObjectDoesNotExist, CollectionDoesNotExist):
+            log.warning("Collection or data object (%s) does not exist", data_object_path)
+            return -1
+        finally:
+            log.debug("irods_pt _get_size_in_irods: %s", ipt_timer)
 
     # rel_path is file or folder?
     def _data_object_exists(self, rel_path):
-        with managed_session(host=self.host, port=self.port, user=self.username, password=self.password, zone=self.zone, timeout=self.timeout) as session:
-            p = Path(rel_path)
-            data_object_name = p.stem + p.suffix
-            subcollection_name = p.parent
+        ipt_timer = ExecutionTimer()
+        p = Path(rel_path)
+        data_object_name = p.stem + p.suffix
+        subcollection_name = p.parent
 
-            collection_path = self.home + "/" + str(subcollection_name)
-            data_object_path = collection_path + "/" + str(data_object_name)
+        collection_path = f"{self.home}/{str(subcollection_name)}"
+        data_object_path = f"{collection_path}/{str(data_object_name)}"
 
-            try:
-                session.data_objects.get(data_object_path)
-                return True
-            except (DataObjectDoesNotExist, CollectionDoesNotExist):
-                log.debug("Collection or data object (%s) does not exist", data_object_path)
-                return False
-            except NetworkException as e:
-                log.exception(e)
-                return False
+        try:
+            self.session.data_objects.get(data_object_path)
+            return True
+        except (DataObjectDoesNotExist, CollectionDoesNotExist):
+            log.debug("Collection or data object (%s) does not exist", data_object_path)
+            return False
+        finally:
+            log.debug("irods_pt _data_object_exists: %s", ipt_timer)
 
     def _in_cache(self, rel_path):
         """ Check if the given dataset is in the local cache and return True if so. """
@@ -339,6 +331,7 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         return os.path.exists(cache_path)
 
     def _pull_into_cache(self, rel_path):
+        ipt_timer = ExecutionTimer()
         # Ensure the cache directory structure exists (e.g., dataset_#_files/)
         rel_path_dir = os.path.dirname(rel_path)
         if not os.path.exists(self._get_cache_path(rel_path_dir)):
@@ -346,40 +339,42 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         # Now pull in the file
         file_ok = self._download(rel_path)
         self._fix_permissions(self._get_cache_path(rel_path_dir))
+        log.debug("irods_pt _pull_into_cache: %s", ipt_timer)
         return file_ok
 
     def _download(self, rel_path):
-        with managed_session(host=self.host, port=self.port, user=self.username, password=self.password, zone=self.zone, timeout=self.timeout) as session:
-            log.debug("Pulling data object '%s' into cache to %s", rel_path, self._get_cache_path(rel_path))
+        ipt_timer = ExecutionTimer()
+        log.debug("Pulling data object '%s' into cache to %s", rel_path, self._get_cache_path(rel_path))
 
-            p = Path(rel_path)
-            data_object_name = p.stem + p.suffix
-            subcollection_name = p.parent
+        p = Path(rel_path)
+        data_object_name = p.stem + p.suffix
+        subcollection_name = p.parent
 
-            collection_path = self.home + "/" + str(subcollection_name)
-            data_object_path = collection_path + "/" + str(data_object_name)
-            data_obj = None
+        collection_path = f"{self.home}/{str(subcollection_name)}"
+        data_object_path = f"{collection_path}/{str(data_object_name)}"
+        data_obj = None
 
-            try:
-                data_obj = session.data_objects.get(data_object_path)
-            except (DataObjectDoesNotExist, CollectionDoesNotExist):
-                log.warn("Collection or data object (%s) does not exist", data_object_path)
-                return False
-            except NetworkException as e:
-                log.exception(e)
-                return False
+        try:
+            data_obj = self.session.data_objects.get(data_object_path)
+        except (DataObjectDoesNotExist, CollectionDoesNotExist):
+            log.warning("Collection or data object (%s) does not exist", data_object_path)
+            return False
+        finally:
+            log.debug("irods_pt _download: %s", ipt_timer)
 
-            if self.cache_size > 0 and data_obj.__sizeof__() > self.cache_size:
-                log.critical("File %s is larger (%s) than the cache size (%s). Cannot download.",
-                            rel_path, data_obj.__sizeof__(), self.cache_size)
-                return False
+        if self.cache_size > 0 and data_obj.__sizeof__() > self.cache_size:
+            log.critical("File %s is larger (%s) than the cache size (%s). Cannot download.",
+                        rel_path, data_obj.__sizeof__(), self.cache_size)
+            log.debug("irods_pt _download: %s", ipt_timer)
+            return False
 
-            log.debug("Pulled data object '%s' into cache to %s", rel_path, self._get_cache_path(rel_path))
+        log.debug("Pulled data object '%s' into cache to %s", rel_path, self._get_cache_path(rel_path))
 
-            with data_obj.open('r') as data_obj_fp, open(self._get_cache_path(rel_path), "wb") as cache_fp:
-                for chunk in iter(partial(data_obj_fp.read, CHUNK_SIZE), b''):
-                    cache_fp.write(chunk)
-            return True
+        with data_obj.open('r') as data_obj_fp, open(self._get_cache_path(rel_path), "wb") as cache_fp:
+            for chunk in iter(partial(data_obj_fp.read, CHUNK_SIZE), b''):
+                cache_fp.write(chunk)
+        log.debug("irods_pt _download: %s", ipt_timer)
+        return True
 
     def _push_to_irods(self, rel_path, source_file=None, from_string=None):
         """
@@ -390,74 +385,83 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         still using ``rel_path`` for collection and object store names.
         If ``from_string`` is provided, set contents of the file to the value of the string.
         """
-        with managed_session(host=self.host, port=self.port, user=self.username, password=self.password, zone=self.zone, timeout=self.timeout) as session:
-            p = Path(rel_path)
-            data_object_name = p.stem + p.suffix
-            subcollection_name = p.parent
+        ipt_timer = ExecutionTimer()
+        p = Path(rel_path)
+        data_object_name = p.stem + p.suffix
+        subcollection_name = p.parent
 
-            source_file = source_file if source_file else self._get_cache_path(rel_path)
-            options = {kw.FORCE_FLAG_KW: ''}
-
-            if os.path.exists(source_file):
-                # Check if the data object exists in iRODS
-                collection_path = self.home + "/" + str(subcollection_name)
-                data_object_path = collection_path + "/" + str(data_object_name)
-                exists = False
-                try:
-                    exists = session.data_objects.exists(data_object_path)
-
-                    if os.path.getsize(source_file) == 0 and exists:
-                        log.debug("Wanted to push file '%s' to iRODS collection '%s' but its size is 0; skipping.", source_file, rel_path)
-                        return True
-
-                    if from_string:
-                        data_obj = session.data_objects.create(data_object_path, self.resource, **options)
-                        with data_obj.open('w') as data_obj_fp:
-                            data_obj_fp.write(from_string)
-                        log.debug("Pushed data from string '%s' to collection '%s'", from_string, data_object_path)
-                    else:
-                        start_time = datetime.now()
-                        log.debug("Pushing cache file '%s' of size %s bytes to collection '%s'", source_file, os.path.getsize(source_file), rel_path)
-
-                        # Create sub-collection first
-                        session.collections.create(collection_path, recurse=True)
-                        data_obj = session.data_objects.create(data_object_path, self.resource, **options)
-
-                        # Write to file in subcollection created above
-                        with open(source_file, 'rb') as content_file, data_obj.open('w') as data_obj_fp:
-                            for chunk in iter(partial(content_file.read, CHUNK_SIZE), b''):
-                                data_obj_fp.write(chunk)
-
-                        end_time = datetime.now()
-                        log.debug("Pushed cache file '%s' to collection '%s' (%s bytes transfered in %s sec)",
-                                source_file, rel_path, os.path.getsize(source_file), end_time - start_time)
-                    return True
-                except NetworkException as e:
-                    log.exception(e)
-                    return False
+        source_file = source_file if source_file else self._get_cache_path(rel_path)
+        options = {kw.FORCE_FLAG_KW: ''}
 
+        if not os.path.exists(source_file):
             log.error("Tried updating key '%s' from source file '%s', but source file does not exist.", rel_path, source_file)
             return False
 
+        # Check if the data object exists in iRODS
+        collection_path = f"{self.home}/{str(subcollection_name)}"
+        data_object_path = f"{collection_path}/{str(data_object_name)}"
+        exists = False
+        try:
+            exists = self.session.data_objects.exists(data_object_path)
+
+            if os.path.getsize(source_file) == 0 and exists:
+                log.debug("Wanted to push file '%s' to iRODS collection '%s' but its size is 0; skipping.", source_file, rel_path)
+                return True
+
+            # Create sub-collection first
+            self.session.collections.create(collection_path, recurse=True)
+
+            # Create data object
+            data_obj = self.session.data_objects.create(data_object_path, self.resource, **options)
+
+            if from_string:
+                # Save 'from_string' as a file
+                with data_obj.open('w') as data_obj_fp:
+                    data_obj_fp.write(from_string)
+
+                # Add file containing 'from_string' to the irods collection, since
+                # put() expects a file as input. Get file name from data object's 'desc' field
+                self.session.data_objects.put(data_obj.desc, f"{collection_path}/", **options)
+
+                log.debug("Pushed data from string '%s' to collection '%s'", from_string, data_object_path)
+            else:
+                start_time = datetime.now()
+                log.debug("Pushing cache file '%s' of size %s bytes to collection '%s'", source_file, os.path.getsize(source_file), rel_path)
+
+                # Add the source file to the irods collection
+                self.session.data_objects.put(source_file, f"{collection_path}/", **options)
+
+                end_time = datetime.now()
+                log.debug("Pushed cache file '%s' to collection '%s' (%s bytes transfered in %s sec)",
+                        source_file, rel_path, os.path.getsize(source_file), (end_time - start_time).total_seconds())
+            return True
+        finally:
+            log.debug("irods_pt _push_to_irods: %s", ipt_timer)
+
     def file_ready(self, obj, **kwargs):
         """
         A helper method that checks if a file corresponding to a dataset is
         ready and available to be used. Return ``True`` if so, ``False`` otherwise.
         """
+        ipt_timer = ExecutionTimer()
         rel_path = self._construct_path(obj, **kwargs)
         # Make sure the size in cache is available in its entirety
         if self._in_cache(rel_path):
             if os.path.getsize(self._get_cache_path(rel_path)) == self._get_size_in_irods(rel_path):
+                log.debug("irods_pt _file_ready: %s", ipt_timer)
                 return True
             log.debug("Waiting for dataset %s to transfer from OS: %s/%s", rel_path,
                       os.path.getsize(self._get_cache_path(rel_path)), self._get_size_in_irods(rel_path))
+        log.debug("irods_pt _file_ready: %s", ipt_timer)
         return False
 
     def _exists(self, obj, **kwargs):
+        ipt_timer = ExecutionTimer()
         rel_path = self._construct_path(obj, **kwargs)
 
         # Check cache and irods
         if self._in_cache(rel_path) or self._data_object_exists(rel_path):
+            log.debug("irods_pt _exists: %s", ipt_timer)
             return True
 
         # dir_only does not get synced so shortcut the decision
@@ -467,10 +471,13 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
             # for JOB_WORK directory
             if not os.path.exists(rel_path):
                 os.makedirs(rel_path)
+            log.debug("irods_pt _exists: %s", ipt_timer)
             return True
+        log.debug("irods_pt _exists: %s", ipt_timer)
         return False
 
     def _create(self, obj, **kwargs):
+        ipt_timer = ExecutionTimer()
         if not self._exists(obj, **kwargs):
             # Pull out locally used fields
             extra_dir = kwargs.get('extra_dir', None)
@@ -494,9 +501,10 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
                 os.makedirs(cache_dir)
 
             if not dir_only:
-                rel_path = os.path.join(rel_path, alt_name if alt_name else "dataset_%s.dat" % self._get_object_id(obj))
+                rel_path = os.path.join(rel_path, alt_name if alt_name else f"dataset_{self._get_object_id(obj)}.dat")
                 open(os.path.join(self.staging_path, rel_path), 'w').close()
                 self._push_to_irods(rel_path, from_string='')
+        log.debug("irods_pt _create: %s", ipt_timer)
 
     def _empty(self, obj, **kwargs):
         if self._exists(obj, **kwargs):
@@ -506,90 +514,90 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
                                  % (str(obj), str(kwargs)))
 
     def _size(self, obj, **kwargs):
+        ipt_timer = ExecutionTimer()
         rel_path = self._construct_path(obj, **kwargs)
         if self._in_cache(rel_path):
             try:
                 return os.path.getsize(self._get_cache_path(rel_path))
             except OSError as ex:
-                log.info("Could not get size of file '%s' in local cache, will try S3. Error: %s", rel_path, ex)
+                log.info("Could not get size of file '%s' in local cache, will try iRODS. Error: %s", rel_path, ex)
+            finally:
+                log.debug("irods_pt _size: %s", ipt_timer)
         elif self._exists(obj, **kwargs):
+            log.debug("irods_pt _size: %s", ipt_timer)
             return self._get_size_in_irods(rel_path)
         log.warning("Did not find dataset '%s', returning 0 for size", rel_path)
+        log.debug("irods_pt _size: %s", ipt_timer)
         return 0
 
     def _delete(self, obj, entire_dir=False, **kwargs):
-        with managed_session(host=self.host, port=self.port, user=self.username, password=self.password, zone=self.zone, timeout=self.timeout) as session:
-            rel_path = self._construct_path(obj, **kwargs)
-            extra_dir = kwargs.get('extra_dir', None)
-            base_dir = kwargs.get('base_dir', None)
-            dir_only = kwargs.get('dir_only', False)
-            obj_dir = kwargs.get('obj_dir', False)
+        ipt_timer = ExecutionTimer()
+        rel_path = self._construct_path(obj, **kwargs)
+        extra_dir = kwargs.get('extra_dir', None)
+        base_dir = kwargs.get('base_dir', None)
+        dir_only = kwargs.get('dir_only', False)
+        obj_dir = kwargs.get('obj_dir', False)
 
-            try:
-                # Remove temparory data in JOB_WORK directory
-                if base_dir and dir_only and obj_dir:
-                    shutil.rmtree(os.path.abspath(rel_path))
+        try:
+            # Remove temparory data in JOB_WORK directory
+            if base_dir and dir_only and obj_dir:
+                shutil.rmtree(os.path.abspath(rel_path))
+                return True
+
+            # For the case of extra_files, because we don't have a reference to
+            # individual files we need to remove the entire directory structure
+            # with all the files in it. This is easy for the local file system,
+            # but requires iterating through each individual key in irods and deleing it.
+            if entire_dir and extra_dir:
+                shutil.rmtree(self._get_cache_path(rel_path), ignore_errors=True)
+
+                col_path = f"{self.home}/{str(rel_path)}"
+                col = None
+                try:
+                    col = self.session.collections.get(col_path)
+                except CollectionDoesNotExist:
+                    log.warning("Collection (%s) does not exist!", col_path)
+                    return False
+
+                cols = col.walk()
+                # Traverse the tree only one level deep
+                for _ in range(2):
+                    # get next result
+                    _, _, data_objects = next(cols)
+
+                    # Delete data objects
+                    for data_object in data_objects:
+                        data_object.unlink(force=True)
+
+                return True
+
+            else:
+                # Delete from cache first
+                unlink(self._get_cache_path(rel_path), ignore_errors=True)
+                # Delete from irods as well
+                p = Path(rel_path)
+                data_object_name = p.stem + p.suffix
+                subcollection_name = p.parent
+
+                collection_path = f"{self.home}/{str(subcollection_name)}"
+                data_object_path = f"{collection_path}/{str(data_object_name)}"
+
+                try:
+                    data_obj = self.session.data_objects.get(data_object_path)
+                    # remove object
+                    data_obj.unlink(force=True)
                     return True
-
-                # For the case of extra_files, because we don't have a reference to
-                # individual files we need to remove the entire directory structure
-                # with all the files in it. This is easy for the local file system,
-                # but requires iterating through each individual key in irods and deleing it.
-                if entire_dir and extra_dir:
-                    shutil.rmtree(self._get_cache_path(rel_path))
-
-                    col_path = self.home + "/" + str(rel_path)
-                    col = None
-                    try:
-                        col = session.collections.get(col_path)
-                    except CollectionDoesNotExist:
-                        log.warn("Collection (%s) does not exist!", col_path)
-                        return False
-                    except NetworkException as e:
-                        log.exception(e)
-                        return False
-
-                    cols = col.walk()
-                    # Traverse the tree only one level deep
-                    for _ in range(2):
-                        # get next result
-                        _, _, data_objects = next(cols)
-
-                        # Delete data objects
-                        for data_object in data_objects:
-                            data_object.unlink(force=True)
-
+                except (DataObjectDoesNotExist, CollectionDoesNotExist):
+                    log.info("Collection or data object (%s) does not exist", data_object_path)
                     return True
-
-                else:
-                    # Delete from cache first
-                    os.unlink(self._get_cache_path(rel_path))
-                    # Delete from irods as well
-                    p = Path(rel_path)
-                    data_object_name = p.stem + p.suffix
-                    subcollection_name = p.parent
-
-                    collection_path = self.home + "/" + str(subcollection_name)
-                    data_object_path = collection_path + "/" + str(data_object_name)
-
-                    try:
-                        data_obj = session.data_objects.get(data_object_path)
-                        # remove object
-                        data_obj.unlink(force=True)
-                        return True
-                    except (DataObjectDoesNotExist, CollectionDoesNotExist):
-                        log.info("Collection or data object (%s) does not exist", data_object_path)
-                        return True
-                    except NetworkException as e:
-                        log.exception(e)
-                        return False
-            except OSError:
-                log.exception('%s delete error', self._get_filename(obj, **kwargs))
-            except NetworkException as e:
-                log.exception(e)
-            return False
+        except OSError:
+            log.exception('%s delete error', self._get_filename(obj, **kwargs))
+        finally:
+            log.debug("irods_pt _delete: %s", ipt_timer)
+        return False
 
     def _get_data(self, obj, start=0, count=-1, **kwargs):
+        ipt_timer = ExecutionTimer()
         rel_path = self._construct_path(obj, **kwargs)
         # Check cache first and get file if not there
         if not self._in_cache(rel_path):
@@ -599,9 +607,11 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         data_file.seek(start)
         content = data_file.read(count)
         data_file.close()
+        log.debug("irods_pt _get_data: %s", ipt_timer)
         return content
 
     def _get_filename(self, obj, **kwargs):
+        ipt_timer = ExecutionTimer()
         base_dir = kwargs.get('base_dir', None)
         dir_only = kwargs.get('dir_only', False)
         obj_dir = kwargs.get('obj_dir', False)
@@ -609,6 +619,7 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
 
         # for JOB_WORK directory
         if base_dir and dir_only and obj_dir:
+            log.debug("irods_pt _get_filename: %s", ipt_timer)
             return os.path.abspath(rel_path)
 
         cache_path = self._get_cache_path(rel_path)
@@ -622,28 +633,33 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         #     return cache_path
         # Check if the file exists in the cache first
         if self._in_cache(rel_path):
+            log.debug("irods_pt _get_filename: %s", ipt_timer)
             return cache_path
         # Check if the file exists in persistent storage and, if it does, pull it into cache
         elif self._exists(obj, **kwargs):
             if dir_only:  # Directories do not get pulled into cache
+                log.debug("irods_pt _get_filename: %s", ipt_timer)
                 return cache_path
             else:
                 if self._pull_into_cache(rel_path):
+                    log.debug("irods_pt _get_filename: %s", ipt_timer)
                     return cache_path
         # For the case of retrieving a directory only, return the expected path
         # even if it does not exist.
         # if dir_only:
         #     return cache_path
+        log.debug("irods_pt _get_filename: %s", ipt_timer)
         raise ObjectNotFound('objectstore.get_filename, no cache_path: %s, kwargs: %s'
                              % (str(obj), str(kwargs)))
         # return cache_path # Until the upload tool does not explicitly create the dataset, return expected path
 
     def _update_from_file(self, obj, file_name=None, create=False, **kwargs):
+        ipt_timer = ExecutionTimer()
         if create:
             self._create(obj, **kwargs)
         if self._exists(obj, **kwargs):
             rel_path = self._construct_path(obj, **kwargs)
-            # Chose whether to use the dataset file itself or an alternate file
+            # Choose whether to use the dataset file itself or an alternate file
             if file_name:
                 source_file = os.path.abspath(file_name)
                 # Copy into cache
@@ -660,8 +676,10 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
             # Update the file on iRODS
             self._push_to_irods(rel_path, source_file)
         else:
+            log.debug("irods_pt _update_from_file: %s", ipt_timer)
             raise ObjectNotFound('objectstore.update_from_file, object does not exist: %s, kwargs: %s'
                                  % (str(obj), str(kwargs)))
+        log.debug("irods_pt _update_from_file: %s", ipt_timer)
 
     # Unlike S3, url is not really applicable to iRODS
     def _get_object_url(self, obj, **kwargs):
@@ -672,8 +690,8 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
             data_object_name = p.stem + p.suffix
             subcollection_name = p.parent
 
-            collection_path = self.home + "/" + str(subcollection_name)
-            data_object_path = collection_path + "/" + str(data_object_name)
+            collection_path = f"{self.home}/{str(subcollection_name)}"
+            data_object_path = f"{collection_path}/{str(data_object_name)}"
 
             return data_object_path
 
